<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>mxtools</name>
    <message>
        <location filename="../mxtools.ui" line="14"/>
        <location filename="../mxtools.cpp" line="364"/>
        <source>MX Tools</source>
        <translation>MX Narzędzia</translation>
    </message>
    <message>
        <location filename="../mxtools.ui" line="47"/>
        <source>About this application</source>
        <translation>O programie</translation>
    </message>
    <message>
        <location filename="../mxtools.ui" line="50"/>
        <source>About...</source>
        <translation>O...</translation>
    </message>
    <message>
        <location filename="../mxtools.ui" line="58"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mxtools.ui" line="116"/>
        <source>Close application</source>
        <translation>Zamknij program</translation>
    </message>
    <message>
        <location filename="../mxtools.ui" line="119"/>
        <source>Close</source>
        <translation>Zamknij</translation>
    </message>
    <message>
        <location filename="../mxtools.ui" line="127"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mxtools.ui" line="149"/>
        <source>Manual</source>
        <translation>Podręcznik</translation>
    </message>
    <message>
        <location filename="../mxtools.ui" line="248"/>
        <source>These MX applications save time and effort with important tasks.</source>
        <translation>Te aplikacje MX oszczędzają Twój czas i wysiłek poświęcony na ważne zadania.</translation>
    </message>
    <message>
        <location filename="../mxtools.ui" line="264"/>
        <source>Hide individual tools from the menu</source>
        <translation>Ukryj poszczególne narzędzia w menu</translation>
    </message>
    <message>
        <location filename="../mxtools.ui" line="283"/>
        <source>search</source>
        <translation>szukaj</translation>
    </message>
    <message>
        <location filename="../mxtools.cpp" line="363"/>
        <source>About MX Tools</source>
        <translation>O MX Narzędzia</translation>
    </message>
    <message>
        <location filename="../mxtools.cpp" line="364"/>
        <source>Version: </source>
        <translation>Wersja:</translation>
    </message>
    <message>
        <location filename="../mxtools.cpp" line="366"/>
        <source>Configuration Tools for MX Linux</source>
        <translation>Narzędzia konfiguracyjne dla MX Linux</translation>
    </message>
    <message>
        <location filename="../mxtools.cpp" line="367"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mxtools.cpp" line="368"/>
        <source>License</source>
        <translation>Licencja</translation>
    </message>
    <message>
        <location filename="../mxtools.cpp" line="369"/>
        <source>Changelog</source>
        <translation>Dziennik zmian</translation>
    </message>
    <message>
        <location filename="../mxtools.cpp" line="370"/>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <location filename="../mxtools.cpp" line="385"/>
        <source>&amp;Close</source>
        <translation>&amp;Zamknij</translation>
    </message>
</context>
</TS>
